summaryrefslogtreecommitdiffstats
path: root/khtml/html/html_tableimpl.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /khtml/html/html_tableimpl.h
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'khtml/html/html_tableimpl.h')
-rw-r--r--khtml/html/html_tableimpl.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/khtml/html/html_tableimpl.h b/khtml/html/html_tableimpl.h
index 277d76d14..76d81ce50 100644
--- a/khtml/html/html_tableimpl.h
+++ b/khtml/html/html_tableimpl.h
@@ -277,7 +277,7 @@ public:
// overrides
virtual NodeImpl *addChild(NodeImpl *child);
virtual NodeImpl *insertBefore ( NodeImpl *newChild, NodeImpl *refChild, int &exceptioncode );
- virtual void tqreplaceChild ( NodeImpl *newChild, NodeImpl *oldChild, int &exceptioncode );
+ virtual void replaceChild ( NodeImpl *newChild, NodeImpl *oldChild, int &exceptioncode );
virtual void removeChild ( NodeImpl *oldChild, int &exceptioncode );
virtual NodeImpl *appendChild ( NodeImpl *newChild, int &exceptioncode );
@@ -285,7 +285,7 @@ public:
virtual void attach();
virtual void close();
/* Tries to tqfind the section containing row number outIndex.
Returns whether it succeeded or not. negative outIndex values
are interpreted as being infinite.
@@ -295,7 +295,7 @@ public:
On failure, outSection points to the last section of the table, and
index is the offset the row would have if there was an additional section.
*/
- bool tqfindRowSection(long inIndex,
+ bool findRowSection(long inIndex,
HTMLTableSectionElementImpl*& outSection,
long& outIndex) const;
protected:
@@ -285,7 +285,7 @@ public:
virtual void attach();
virtual void close();
- /* Tries to tqfind the section containing row number outIndex.
+ /* Tries to find the section containing row number outIndex.
Returns whether it succeeded or not. negative outIndex values
are interpreted as being infinite.